# -*- coding: utf-8 -*-
"""falakpy package initializer.

Provides modules for:
- qibla direction computation
- prayer time calculation
- lunar crescent observation
"""

from . import qibla, prayertime, lunar

__all__ = ["qibla", "prayertime", "lunar"]
